# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import notification_pb2 as notification__pb2


class NotificationApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_subscription = channel.unary_unary(
                '/oi.papi.NotificationApi/create_subscription',
                request_serializer=notification__pb2.SubscriptionCreateRequest.SerializeToString,
                response_deserializer=notification__pb2.SubscriptionCreateResponse.FromString,
                )
        self.list_topic = channel.unary_unary(
                '/oi.papi.NotificationApi/list_topic',
                request_serializer=notification__pb2.TopicListRequest.SerializeToString,
                response_deserializer=notification__pb2.TopicListResponse.FromString,
                )
        self.list_channel = channel.unary_unary(
                '/oi.papi.NotificationApi/list_channel',
                request_serializer=notification__pb2.ChannelListRequest.SerializeToString,
                response_deserializer=notification__pb2.ChannelListResponse.FromString,
                )
        self.delete_subscription = channel.unary_unary(
                '/oi.papi.NotificationApi/delete_subscription',
                request_serializer=notification__pb2.SubscriptionDeleteRequest.SerializeToString,
                response_deserializer=notification__pb2.SubscriptionDeleteResponse.FromString,
                )


class NotificationApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_subscription(self, request, context):
        """
        Create subscription for a specific topic
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_topic(self, request, context):
        """
        Get all the Topics that the user can subscribe to
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_channel(self, request, context):
        """
        Get all the channels that can be used
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_subscription(self, request, context):
        """
        Deletes the specified Subscription.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_subscription': grpc.unary_unary_rpc_method_handler(
                    servicer.create_subscription,
                    request_deserializer=notification__pb2.SubscriptionCreateRequest.FromString,
                    response_serializer=notification__pb2.SubscriptionCreateResponse.SerializeToString,
            ),
            'list_topic': grpc.unary_unary_rpc_method_handler(
                    servicer.list_topic,
                    request_deserializer=notification__pb2.TopicListRequest.FromString,
                    response_serializer=notification__pb2.TopicListResponse.SerializeToString,
            ),
            'list_channel': grpc.unary_unary_rpc_method_handler(
                    servicer.list_channel,
                    request_deserializer=notification__pb2.ChannelListRequest.FromString,
                    response_serializer=notification__pb2.ChannelListResponse.SerializeToString,
            ),
            'delete_subscription': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_subscription,
                    request_deserializer=notification__pb2.SubscriptionDeleteRequest.FromString,
                    response_serializer=notification__pb2.SubscriptionDeleteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.NotificationApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotificationApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_subscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.NotificationApi/create_subscription',
            notification__pb2.SubscriptionCreateRequest.SerializeToString,
            notification__pb2.SubscriptionCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_topic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.NotificationApi/list_topic',
            notification__pb2.TopicListRequest.SerializeToString,
            notification__pb2.TopicListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_channel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.NotificationApi/list_channel',
            notification__pb2.ChannelListRequest.SerializeToString,
            notification__pb2.ChannelListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_subscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.NotificationApi/delete_subscription',
            notification__pb2.SubscriptionDeleteRequest.SerializeToString,
            notification__pb2.SubscriptionDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright 2017-2021 Orbital Insight Inc., all rights reserved.
# Contains confidential and trade secret information.
# Government Users:  Commercial Computer Software - Use governed by
# terms of Orbital Insight commercial license agreement.


import os
from abc import ABC, abstractmethod

import json

import grpc
from terrascope_api import stubs


API_TOKEN = 'TERRASCOPE_API_TOKEN'


class TerrascopeBaseApi(ABC):
    def __init__(self, oi_papi_url, port=443, secure=True, api_token=None, root_certificates_file=None):
        self._oi_papi_url = oi_papi_url
        self._port = port

        self.api_token = os.environ.get(API_TOKEN, "").strip() if api_token is None else api_token.strip()
        if not self.api_token:
            raise ValueError(f'API token must be provided or export {API_TOKEN}=<api_token>')

        self.options = [('grpc.max_send_message_length', -1),
                        ('grpc.max_receive_message_length', -1),
                        ('grpc.max_metadata_size', 16000)]
        service_config_json = json.dumps({
            "methodConfig": [{
                "name": [{}],  # Apply retry to all methods by using [{}]
                "retryPolicy": {
                    "maxAttempts": 5,
                    "initialBackoff": "1.0s",
                    "maxBackoff": "60s",
                    "backoffMultiplier": 2,
                    "retryableStatusCodes": ["UNAVAILABLE"],
                },
            }]
        })
        self.options.append(("grpc.service_config", service_config_json))
        self._channel = self._get_channel(self._get_ssl_channel_credentials(
            secure, root_certificates_file=root_certificates_file))
        self.algorithm = stubs.algorithm.AlgorithmApiStub(self._channel)
        self.algorithm_version = stubs.algorithm_version.AlgorithmVersionApiStub(self._channel)
        self.algorithm_config = stubs.algorithm_config.AlgorithmConfigApiStub(self._channel)
        self.aoi = stubs.aoi.AOIApiStub(self._channel)
        self.aoi_collection = stubs.aoi_collection.AOICollectionApiStub(self._channel)
        self.aoi_version = stubs.aoi_version.AOIVersionApiStub(self._channel)
        self.aoi_transaction = stubs.aoi_transaction.AOITransactionApiStub(self._channel)
        self.aoi_export = stubs.aoi_export.AOIExportApiStub(self._channel)
        self.algorithm_computation = stubs.algorithm_computation.AlgorithmComputationApiStub(self._channel)
        self.analysis = stubs.analysis.AnalysisApiStub(self._channel)
        self.analysis_version = stubs.analysis_version.AnalysisVersionApiStub(self._channel)
        self.credit = stubs.credit.CreditApiStub(self._channel)
        self.result = stubs.result.ResultApiStub(self._channel)
        self.analysis_config = stubs.analysis_config.AnalysisConfigApiStub(self._channel)
        self.analysis_computation = stubs.analysis_computation.AnalysisComputationApiStub(self._channel)
        self.system = stubs.system.SystemApiStub(self._channel)
        self.toi = stubs.toi.TOIApiStub(self._channel)
        self.permission = stubs.permission.PermissionApiStub(self._channel)
        self.user = stubs.user.UserApiStub(self._channel)
        self.user_collection = stubs.user_collection.UserCollectionApiStub(self._channel)
        self.token = stubs.token.TokenApiStub(self._channel)
        self.visualization = stubs.visualization.VisualizationApiStub(self._channel)
        self.tile = stubs.tile.TileApiStub(self._channel)
        self.imagery = stubs.imagery.ImageryApiStub(self._channel)
        self.notification = stubs.notification.NotificationApiStub(self._channel)
        self.data_source = stubs.data_source.DataSourceAPIStub(self._channel)
        self.data_type = stubs.data_type.DataTypeAPIStub(self._channel)

    def _get_ssl_channel_credentials(self, secure, root_certificates_file=None):
        # note: with all defaults, gRPC will search for cert as described here:
        #  https://github.com/grpc/grpc/blob/7a63bd5407d5e14b30f19a5aaf4b6cd1b80f00e1/include/grpc/grpc_security.h#L287
        # for local env, use local_channel_credentials:
        #  https://grpc.github.io/grpc/python/grpc.html#grpc.local_channel_credentials
        if secure:
            root_certificates = None
            if root_certificates_file:
                with open(root_certificates_file, 'rb') as file:
                    root_certificates = file.read()

            return grpc.ssl_channel_credentials(root_certificates=root_certificates,
                                                private_key=None, certificate_chain=None)
        return grpc.local_channel_credentials()

    @abstractmethod
    def _get_channel(self, channel_credentials: grpc.ChannelCredentials):
        ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import algorithm_pb2 as algorithm__pb2


class AlgorithmApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AlgorithmApi/create',
                request_serializer=algorithm__pb2.AlgorithmCreateRequest.SerializeToString,
                response_deserializer=algorithm__pb2.AlgorithmCreateResponse.FromString,
                )
        self.update = channel.unary_unary(
                '/oi.papi.AlgorithmApi/update',
                request_serializer=algorithm__pb2.AlgorithmUpdateRequest.SerializeToString,
                response_deserializer=algorithm__pb2.AlgorithmUpdateResponse.FromString,
                )
        self.get = channel.unary_unary(
                '/oi.papi.AlgorithmApi/get',
                request_serializer=algorithm__pb2.AlgorithmGetRequest.SerializeToString,
                response_deserializer=algorithm__pb2.AlgorithmGetResponse.FromString,
                )
        self.list = channel.unary_unary(
                '/oi.papi.AlgorithmApi/list',
                request_serializer=algorithm__pb2.AlgorithmListRequest.SerializeToString,
                response_deserializer=algorithm__pb2.AlgorithmListResponse.FromString,
                )


class AlgorithmApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create a top level Algorithm object.
        This object is lightweight and is used to connect all versions of an Algorithm together.
        Once an Algorithm has been created, an AlgorithmVersion must be created using a manifest.
        Next an algorithm_config may be created to specify a particular configuration of an AlgorithmVersion,
        which can be used in an AlgorithmComputation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Update the mutable fields of a top level algorithm.
        This should be done rarely and with caution as it will affect all algorithm_versions and algorithm_configs associated with this algorithm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Retrieve the metadata of a particular Algorithm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Retrieve the metadata for all Algorithms that this user has access to and that match the provided search filters, if any.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlgorithmApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=algorithm__pb2.AlgorithmCreateRequest.FromString,
                    response_serializer=algorithm__pb2.AlgorithmCreateResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=algorithm__pb2.AlgorithmUpdateRequest.FromString,
                    response_serializer=algorithm__pb2.AlgorithmUpdateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=algorithm__pb2.AlgorithmGetRequest.FromString,
                    response_serializer=algorithm__pb2.AlgorithmGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=algorithm__pb2.AlgorithmListRequest.FromString,
                    response_serializer=algorithm__pb2.AlgorithmListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AlgorithmApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlgorithmApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AlgorithmApi/create',
            algorithm__pb2.AlgorithmCreateRequest.SerializeToString,
            algorithm__pb2.AlgorithmCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AlgorithmApi/update',
            algorithm__pb2.AlgorithmUpdateRequest.SerializeToString,
            algorithm__pb2.AlgorithmUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AlgorithmApi/get',
            algorithm__pb2.AlgorithmGetRequest.SerializeToString,
            algorithm__pb2.AlgorithmGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AlgorithmApi/list',
            algorithm__pb2.AlgorithmListRequest.SerializeToString,
            algorithm__pb2.AlgorithmListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi_collection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61oi_collection.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"|\n\rAOICollection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x10\n\x08num_aois\x18\x05 \x01(\r\"\x90\x01\n\x07\x41OIInfo\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61oi_version_id\x18\x02 \x01(\t\x12\x10\n\x08\x61oi_name\x18\x03 \x01(\t\x12\x0b\n\x03lat\x18\x04 \x01(\x02\x12\x0c\n\x04long\x18\x05 \x01(\x02\x12\x10\n\x08\x61rea_km2\x18\x06 \x01(\x01\x12\x0c\n\x04geom\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\"*\n\x1a\x41OICollectionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"b\n\x1b\x41OICollectionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12.\n\x0e\x61oi_collection\x18\x02 \x01(\x0b\x32\x16.oi.papi.AOICollection\"_\n\x17\x41OICollectionGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07verbose\x18\x02 \x01(\x08\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"|\n\x18\x41OICollectionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\"\n\x08\x61oi_info\x18\x03 \x03(\x0b\x32\x10.oi.papi.AOIInfo\">\n\x17\x41OICollectionAddRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x61oi_version_ids\x18\x02 \x03(\r\"/\n\x18\x41OICollectionAddResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"A\n\x1a\x41OICollectionRemoveRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x61oi_version_ids\x18\x02 \x03(\r\"2\n\x1b\x41OICollectionRemoveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"5\n\x19\x41OICollectionCloneRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x1a\x41OICollectionCloneResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x19\n\x11\x61oi_collection_id\x18\x02 \x01(\t\"\xc0\x01\n\x18\x41OICollectionListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x32\n\x0emin_created_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\"\x8a\x01\n\x19\x41OICollectionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12/\n\x0f\x61oi_collections\x18\x03 \x03(\x0b\x32\x16.oi.papi.AOICollection2\xf5\x03\n\x10\x41OICollectionApi\x12S\n\x06\x63reate\x12#.oi.papi.AOICollectionCreateRequest\x1a$.oi.papi.AOICollectionCreateResponse\x12J\n\x03get\x12 .oi.papi.AOICollectionGetRequest\x1a!.oi.papi.AOICollectionGetResponse\x12P\n\x05\x63lone\x12\".oi.papi.AOICollectionCloneRequest\x1a#.oi.papi.AOICollectionCloneResponse\x12J\n\x03\x61\x64\x64\x12 .oi.papi.AOICollectionAddRequest\x1a!.oi.papi.AOICollectionAddResponse\x12S\n\x06remove\x12#.oi.papi.AOICollectionRemoveRequest\x1a$.oi.papi.AOICollectionRemoveResponse\x12M\n\x04list\x12!.oi.papi.AOICollectionListRequest\x1a\".oi.papi.AOICollectionListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AOICOLLECTION']._serialized_start=87
  _globals['_AOICOLLECTION']._serialized_end=211
  _globals['_AOIINFO']._serialized_start=214
  _globals['_AOIINFO']._serialized_end=358
  _globals['_AOICOLLECTIONCREATEREQUEST']._serialized_start=360
  _globals['_AOICOLLECTIONCREATEREQUEST']._serialized_end=402
  _globals['_AOICOLLECTIONCREATERESPONSE']._serialized_start=404
  _globals['_AOICOLLECTIONCREATERESPONSE']._serialized_end=502
  _globals['_AOICOLLECTIONGETREQUEST']._serialized_start=504
  _globals['_AOICOLLECTIONGETREQUEST']._serialized_end=599
  _globals['_AOICOLLECTIONGETRESPONSE']._serialized_start=601
  _globals['_AOICOLLECTIONGETRESPONSE']._serialized_end=725
  _globals['_AOICOLLECTIONADDREQUEST']._serialized_start=727
  _globals['_AOICOLLECTIONADDREQUEST']._serialized_end=789
  _globals['_AOICOLLECTIONADDRESPONSE']._serialized_start=791
  _globals['_AOICOLLECTIONADDRESPONSE']._serialized_end=838
  _globals['_AOICOLLECTIONREMOVEREQUEST']._serialized_start=840
  _globals['_AOICOLLECTIONREMOVEREQUEST']._serialized_end=905
  _globals['_AOICOLLECTIONREMOVERESPONSE']._serialized_start=907
  _globals['_AOICOLLECTIONREMOVERESPONSE']._serialized_end=957
  _globals['_AOICOLLECTIONCLONEREQUEST']._serialized_start=959
  _globals['_AOICOLLECTIONCLONEREQUEST']._serialized_end=1012
  _globals['_AOICOLLECTIONCLONERESPONSE']._serialized_start=1014
  _globals['_AOICOLLECTIONCLONERESPONSE']._serialized_end=1090
  _globals['_AOICOLLECTIONLISTREQUEST']._serialized_start=1093
  _globals['_AOICOLLECTIONLISTREQUEST']._serialized_end=1285
  _globals['_AOICOLLECTIONLISTRESPONSE']._serialized_start=1288
  _globals['_AOICOLLECTIONLISTRESPONSE']._serialized_end=1426
  _globals['_AOICOLLECTIONAPI']._serialized_start=1429
  _globals['_AOICOLLECTIONAPI']._serialized_end=1930
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_collection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import user_pb2 as user__pb2
try:
  common__models__pb2 = user__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = user__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.user_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15user_collection.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\nuser.proto\"H\n\x0eUserCollection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x05users\x18\x03 \x03(\x0b\x32\r.oi.papi.User\"J\n\x1bUserCollectionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15parent_collection_ids\x18\x02 \x03(\t\"`\n\x1cUserCollectionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\"^\n\x18UserCollectionGetRequest\x12+\n\ncollection\x18\x01 \x01(\x0b\x32\x17.oi.papi.UserCollection\x12\x15\n\rinclude_users\x18\x02 \x01(\x08\"]\n\x19UserCollectionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\",\n\x19UserCollectionListRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"_\n\x1aUserCollectionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\x0b\x63ollections\x18\x02 \x03(\x0b\x32\x17.oi.papi.UserCollection2\x89\x02\n\x11UserCollectionApi\x12U\n\x06\x63reate\x12$.oi.papi.UserCollectionCreateRequest\x1a%.oi.papi.UserCollectionCreateResponse\x12L\n\x03get\x12!.oi.papi.UserCollectionGetRequest\x1a\".oi.papi.UserCollectionGetResponse\x12O\n\x04list\x12\".oi.papi.UserCollectionListRequest\x1a#.oi.papi.UserCollectionListResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_USERCOLLECTION']._serialized_start=67
  _globals['_USERCOLLECTION']._serialized_end=139
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_start=141
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_end=215
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_start=217
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_end=313
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_start=315
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_end=409
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_start=411
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_end=504
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_start=506
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_end=550
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_start=552
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_end=647
  _globals['_USERCOLLECTIONAPI']._serialized_start=650
  _globals['_USERCOLLECTIONAPI']._serialized_end=915
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import aoi_collection_pb2 as aoi__collection__pb2


class AOICollectionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AOICollectionApi/create',
                request_serializer=aoi__collection__pb2.AOICollectionCreateRequest.SerializeToString,
                response_deserializer=aoi__collection__pb2.AOICollectionCreateResponse.FromString,
                )
        self.get = channel.unary_unary(
                '/oi.papi.AOICollectionApi/get',
                request_serializer=aoi__collection__pb2.AOICollectionGetRequest.SerializeToString,
                response_deserializer=aoi__collection__pb2.AOICollectionGetResponse.FromString,
                )
        self.clone = channel.unary_unary(
                '/oi.papi.AOICollectionApi/clone',
                request_serializer=aoi__collection__pb2.AOICollectionCloneRequest.SerializeToString,
                response_deserializer=aoi__collection__pb2.AOICollectionCloneResponse.FromString,
                )
        self.add = channel.unary_unary(
                '/oi.papi.AOICollectionApi/add',
                request_serializer=aoi__collection__pb2.AOICollectionAddRequest.SerializeToString,
                response_deserializer=aoi__collection__pb2.AOICollectionAddResponse.FromString,
                )
        self.remove = channel.unary_unary(
                '/oi.papi.AOICollectionApi/remove',
                request_serializer=aoi__collection__pb2.AOICollectionRemoveRequest.SerializeToString,
                response_deserializer=aoi__collection__pb2.AOICollectionRemoveResponse.FromString,
                )
        self.list = channel.unary_unary(
                '/oi.papi.AOICollectionApi/list',
                request_serializer=aoi__collection__pb2.AOICollectionListRequest.SerializeToString,
                response_deserializer=aoi__collection__pb2.AOICollectionListResponse.FromString,
                )


class AOICollectionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create an AOICollection to house AOIs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get the metadata about the AOICollection and the AOIs that belong to the specified AOICollection.
        Setting the verbose flag will also include the bytes in wkt format describing the geometry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def clone(self, request, context):
        """
        Creates a copy of the provided AOICollection resulting in a new AOICollection which is not associated with the original in any way.
        This is a shallow copy, only the pointers to the underlying aoi_id and aoi_versions are copied, but the underlying AOIs remain the same between both collections.
        Once an AOICollection is cloned and a new AOICollection is created, the new AOICollection can be modified before it is used as part of a computation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add(self, request, context):
        """
        Add AOI's to a given AOICollection. Cannot add to a "locked" AOICollection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def remove(self, request, context):
        """
        Remove AOI's from a given AOICollection (AOI's must be part of that collection). Cannot remove from a "locked" collection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Returns the list of all AOICollections that the requester has access to.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AOICollectionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=aoi__collection__pb2.AOICollectionCreateRequest.FromString,
                    response_serializer=aoi__collection__pb2.AOICollectionCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=aoi__collection__pb2.AOICollectionGetRequest.FromString,
                    response_serializer=aoi__collection__pb2.AOICollectionGetResponse.SerializeToString,
            ),
            'clone': grpc.unary_unary_rpc_method_handler(
                    servicer.clone,
                    request_deserializer=aoi__collection__pb2.AOICollectionCloneRequest.FromString,
                    response_serializer=aoi__collection__pb2.AOICollectionCloneResponse.SerializeToString,
            ),
            'add': grpc.unary_unary_rpc_method_handler(
                    servicer.add,
                    request_deserializer=aoi__collection__pb2.AOICollectionAddRequest.FromString,
                    response_serializer=aoi__collection__pb2.AOICollectionAddResponse.SerializeToString,
            ),
            'remove': grpc.unary_unary_rpc_method_handler(
                    servicer.remove,
                    request_deserializer=aoi__collection__pb2.AOICollectionRemoveRequest.FromString,
                    response_serializer=aoi__collection__pb2.AOICollectionRemoveResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=aoi__collection__pb2.AOICollectionListRequest.FromString,
                    response_serializer=aoi__collection__pb2.AOICollectionListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AOICollectionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AOICollectionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOICollectionApi/create',
            aoi__collection__pb2.AOICollectionCreateRequest.SerializeToString,
            aoi__collection__pb2.AOICollectionCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOICollectionApi/get',
            aoi__collection__pb2.AOICollectionGetRequest.SerializeToString,
            aoi__collection__pb2.AOICollectionGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def clone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOICollectionApi/clone',
            aoi__collection__pb2.AOICollectionCloneRequest.SerializeToString,
            aoi__collection__pb2.AOICollectionCloneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def add(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOICollectionApi/add',
            aoi__collection__pb2.AOICollectionAddRequest.SerializeToString,
            aoi__collection__pb2.AOICollectionAddResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def remove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOICollectionApi/remove',
            aoi__collection__pb2.AOICollectionRemoveRequest.SerializeToString,
            aoi__collection__pb2.AOICollectionRemoveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOICollectionApi/list',
            aoi__collection__pb2.AOICollectionListRequest.SerializeToString,
            aoi__collection__pb2.AOICollectionListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permission.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10permission.proto\x12\x12oi.papi.permission\x1a\x13\x63ommon_models.proto\"\xab\x04\n\nPermission\x12\x42\n\rresource_type\x18\x01 \x01(\x0e\x32+.oi.papi.permission.Permission.ResourceType\x12\x14\n\x0cresource_ids\x18\x02 \x03(\t\x12\x13\n\x0bsubject_ids\x18\x03 \x03(\t\x12G\n\x10permission_types\x18\x04 \x03(\x0e\x32-.oi.papi.permission.Permission.PermissionType\"\xda\x01\n\x0cResourceType\x12$\n UNKNOWN_PERMISSION_RESOURCE_TYPE\x10\x00\x12\r\n\tALGORITHM\x10\x01\x12\x19\n\x15\x41LGORITHM_COMPUTATION\x10\x02\x12\x14\n\x10\x41LGORITHM_CONFIG\x10\x03\x12\x0c\n\x08\x41NALYSIS\x10\x04\x12\x18\n\x14\x41NALYSIS_COMPUTATION\x10\x05\x12\x13\n\x0f\x41NALYSIS_CONFIG\x10\x06\x12\x12\n\x0e\x41OI_COLLECTION\x10\x07\x12\n\n\x06RESULT\x10\x08\x12\x07\n\x03TOI\x10\t\"M\n\x0ePermissionType\x12\x1b\n\x17UNKNOWN_PERMISSION_TYPE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\"9\n\x0e\x43ollectionType\x12\x1b\n\x17UNKNOWN_COLLECTION_TYPE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\"N\n\x17PermissionCreateRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"/\n\x18PermissionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"N\n\x17PermissionDeleteRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"/\n\x18PermissionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xd9\x01\n\rPermissionApi\x12\x63\n\x06\x63reate\x12+.oi.papi.permission.PermissionCreateRequest\x1a,.oi.papi.permission.PermissionCreateResponse\x12\x63\n\x06\x64\x65lete\x12+.oi.papi.permission.PermissionDeleteRequest\x1a,.oi.papi.permission.PermissionDeleteResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'permission_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PERMISSION']._serialized_start=62
  _globals['_PERMISSION']._serialized_end=617
  _globals['_PERMISSION_RESOURCETYPE']._serialized_start=261
  _globals['_PERMISSION_RESOURCETYPE']._serialized_end=479
  _globals['_PERMISSION_PERMISSIONTYPE']._serialized_start=481
  _globals['_PERMISSION_PERMISSIONTYPE']._serialized_end=558
  _globals['_PERMISSION_COLLECTIONTYPE']._serialized_start=560
  _globals['_PERMISSION_COLLECTIONTYPE']._serialized_end=617
  _globals['_PERMISSIONCREATEREQUEST']._serialized_start=619
  _globals['_PERMISSIONCREATEREQUEST']._serialized_end=697
  _globals['_PERMISSIONCREATERESPONSE']._serialized_start=699
  _globals['_PERMISSIONCREATERESPONSE']._serialized_end=746
  _globals['_PERMISSIONDELETEREQUEST']._serialized_start=748
  _globals['_PERMISSIONDELETEREQUEST']._serialized_end=826
  _globals['_PERMISSIONDELETERESPONSE']._serialized_start=828
  _globals['_PERMISSIONDELETERESPONSE']._serialized_end=875
  _globals['_PERMISSIONAPI']._serialized_start=878
  _globals['_PERMISSIONAPI']._serialized_end=1095
# @@protoc_insertion_point(module_scope)



import importlib
from typing import Callable, Union

import grpc
from grpc.aio import \
    UnaryUnaryClientInterceptor,\
    UnaryStreamClientInterceptor,\
    StreamUnaryClientInterceptor,\
    StreamStreamClientInterceptor,\
    ClientCallDetails
from grpc.aio._call import \
    UnaryUnaryCall,\
    UnaryStreamCall,\
    StreamUnaryCall,\
    StreamStreamCall

from grpc.aio._typing import RequestType, ResponseIterableType, ResponseType, \
    RequestIterableType

if importlib.util.find_spec('oi_tracing'):
    from oi_tracing import inject_current_span
else:
    def inject_current_span(_headers):
        pass

if importlib.util.find_spec('mercury_client'):
    from mercury_client.context import context_as_dict
else:
    def context_as_dict():
        return {}


def inject_current_context_into_header(client_call_details: ClientCallDetails)\
        -> ClientCallDetails:

    if client_call_details.metadata is None:  # grpc.aio._metadata.Metadata
        client_call_details.metadata = grpc.aio._metadata.Metadata()

    new_headers = context_as_dict()

    inject_current_span(new_headers)
    # inject_current_auth(new_headers)

    for k, v in new_headers.items():
        client_call_details.metadata.add(k, str(v))
    # todo not clear if it is safe to modify or a new copy needs to be made
    #   at this point returning modified original object
    return client_call_details


class ContextInjectorUnaryUnary(UnaryUnaryClientInterceptor):

    async def intercept_unary_unary(
            self, continuation: Callable[[ClientCallDetails, RequestType],
                                         UnaryUnaryCall],
            client_call_details: ClientCallDetails,
            request: RequestType) \
            -> Union[UnaryUnaryCall, ResponseType]:
        new_details = inject_current_context_into_header(client_call_details)
        response = continuation(new_details, request)
        return await response


class ContextInjectorUnaryStream(UnaryStreamClientInterceptor):

    async def intercept_unary_stream(
            self,
            continuation: Callable[[ClientCallDetails, RequestType],
                                   UnaryStreamCall],
            client_call_details: ClientCallDetails,
            request: RequestType) \
            -> Union[ResponseIterableType, UnaryStreamCall]:
        new_details = inject_current_context_into_header(client_call_details)
        response = continuation(new_details, request)
        return await response


class ContextInjectorStreamUnary(StreamUnaryClientInterceptor):

    async def intercept_stream_unary(
            self,
            continuation: Callable[[ClientCallDetails, RequestType],
                                   StreamUnaryCall],
            client_call_details: ClientCallDetails,
            request_iterator: RequestIterableType,
    ) -> StreamUnaryCall:
        new_details = inject_current_context_into_header(client_call_details)
        response = continuation(new_details, request_iterator)
        return await response


class ContextInjectorStreamStream(StreamStreamClientInterceptor):
    async def intercept_stream_stream(
            self,
            continuation: Callable[[ClientCallDetails, RequestType],
                                   StreamStreamCall],
            client_call_details: ClientCallDetails,
            request_iterator: RequestIterableType,
    ) -> Union[ResponseIterableType, StreamStreamCall]:
        new_details = inject_current_context_into_header(client_call_details)
        response = continuation(new_details, request_iterator)
        return await response



# Copyright 2017-2021 Orbital Insight Inc., all rights reserved.
# Contains confidential and trade secret information.
# Government Users:  Commercial Computer Software - Use governed by
# terms of Orbital Insight commercial license agreement.


import grpc
from terrascope_api.terrascope_base_api import TerrascopeBaseApi
from terrascope_api import models
from terrascope_api.async_interceptors import (
    ContextInjectorUnaryUnary, ContextInjectorStreamUnary, ContextInjectorUnaryStream, ContextInjectorStreamStream
)


class TerrascopeAsyncClient:
    def __init__(self, oi_papi_url, port=443, secure=True, api_token=None, root_certificates_file=None):
        self.api = TerrascopeAsyncApi(oi_papi_url, port, secure, api_token=api_token,
                                      root_certificates_file=root_certificates_file)
        self.models = models


class TerrascopeAsyncApi(TerrascopeBaseApi):
    def __init__(self, oi_papi_url, port=443, secure=True, api_token=None, root_certificates_file=None):
        self.context_injecting_interceptors = [
            # materialize distributed context from request headers
            ContextInjectorUnaryUnary(), ContextInjectorUnaryStream(),
            ContextInjectorStreamUnary(), ContextInjectorStreamStream()
        ]
        super(TerrascopeAsyncApi, self).__init__(oi_papi_url, port, secure, api_token,
                                                 root_certificates_file)

    def _get_channel(self, channel_credentials: grpc.ChannelCredentials):
        token_creds = grpc.access_token_call_credentials(self.api_token)
        creds = grpc.composite_channel_credentials(channel_credentials, token_creds)
        return grpc.aio.secure_channel(f"{self._oi_papi_url}:{self._port}",
                                       creds,
                                       options=self.options,
                                       compression=None,
                                       interceptors=self.context_injecting_interceptors)

    # TODO: async destructor
    def __adel__(self):
        self._channel.close()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12notification.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"\xc3\x01\n\x19SubscriptionCreateRequest\x12\x46\n\rsubscriptions\x18\x01 \x03(\x0b\x32/.oi.papi.SubscriptionCreateRequest.Subscription\x1a^\n\x0cSubscription\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12(\n\x07\x66ilters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"K\n\x1aSubscriptionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10subscription_ids\x18\x02 \x03(\t\"(\n\x05Topic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\'\n\x10TopicListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"H\n\x11TopicListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1e\n\x06topics\x18\x02 \x03(\x0b\x32\x0e.oi.papi.Topic\"#\n\x07\x43hannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\")\n\x12\x43hannelListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"N\n\x13\x43hannelListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\"\n\x08\x63hannels\x18\x02 \x03(\x0b\x32\x10.oi.papi.Channel\"(\n\x19SubscriptionDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"1\n\x1aSubscriptionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xe1\x02\n\x0fNotificationApi\x12^\n\x13\x63reate_subscription\x12\".oi.papi.SubscriptionCreateRequest\x1a#.oi.papi.SubscriptionCreateResponse\x12\x43\n\nlist_topic\x12\x19.oi.papi.TopicListRequest\x1a\x1a.oi.papi.TopicListResponse\x12I\n\x0clist_channel\x12\x1b.oi.papi.ChannelListRequest\x1a\x1c.oi.papi.ChannelListResponse\x12^\n\x13\x64\x65lete_subscription\x12\".oi.papi.SubscriptionDeleteRequest\x1a#.oi.papi.SubscriptionDeleteResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_start=83
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_end=278
  _globals['_SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION']._serialized_start=184
  _globals['_SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION']._serialized_end=278
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_start=280
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_end=355
  _globals['_TOPIC']._serialized_start=357
  _globals['_TOPIC']._serialized_end=397
  _globals['_TOPICLISTREQUEST']._serialized_start=399
  _globals['_TOPICLISTREQUEST']._serialized_end=438
  _globals['_TOPICLISTRESPONSE']._serialized_start=440
  _globals['_TOPICLISTRESPONSE']._serialized_end=512
  _globals['_CHANNEL']._serialized_start=514
  _globals['_CHANNEL']._serialized_end=549
  _globals['_CHANNELLISTREQUEST']._serialized_start=551
  _globals['_CHANNELLISTREQUEST']._serialized_end=592
  _globals['_CHANNELLISTRESPONSE']._serialized_start=594
  _globals['_CHANNELLISTRESPONSE']._serialized_end=672
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_start=674
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_end=714
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_start=716
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_end=765
  _globals['_NOTIFICATIONAPI']._serialized_start=768
  _globals['_NOTIFICATIONAPI']._serialized_end=1121
# @@protoc_insertion_point(module_scope)
